@@ -7,8 +7,8 @@ def test_embed_documents_does_not_break_element_to_dict(mocker):
     mock_client = mocker.MagicMock()
     mock_client.embed_documents.return_value = [1, 2]
 
-    # Mock create_client to return our mock_client
-    mocker.patch.object(OctoAIEmbeddingEncoder, "create_client", return_value=mock_client)
+    # Mock get_client to return our mock_client
+    mocker.patch.object(OctoAiEmbeddingConfig, "get_client", return_value=mock_client)
 
     encoder = OctoAIEmbeddingEncoder(config=OctoAiEmbeddingConfig(api_key="api_key"))
     elements = encoder.embed_documents(
