@@ -187,6 +187,11 @@ def test_partition_json_works_with_empty_string():
     assert partition_json(text="") == []
 
 
+def test_partition_json_fails_with_empty_item():
+    with pytest.raises(ValueError):
+        partition_json(text="{}")
+
+
 def test_partition_json_works_with_empty_list():
     assert partition_json(text="[]") == []
 
@@ -288,6 +293,12 @@ def test_partition_json_from_text_prefers_metadata_last_modified():
 # ------------------------------------------------------------------------------------------------
 
 
+def test_partition_json_raises_with_unprocessable_json_array():
+    text = '[{"invalid": "schema"}]'
+    with pytest.raises(ValueError):
+        partition_json(text=text)
+
+
 def test_partition_json_raises_with_unprocessable_json():
     # NOTE(robinson) - This is unprocessable because it is not a list of dicts,
     # per the Unstructured ISD format
