@@ -18,8 +18,9 @@ from __future__ import annotations
 import uuid
 from copy import copy
 from enum import Enum
-from typing import List, Optional
+from typing import Any, List, Optional
 
+from bs4 import BeautifulSoup
 from pydantic import BaseModel, Field
 
 
@@ -41,62 +42,94 @@ class ElementTypeEnum(str, Enum):
 
 
 class OntologyElement(BaseModel):
-    text: Optional[str] = Field(None, description="Text content of the element")
+    text: Optional[str] = Field("", description="Text content of the element")
     css_class_name: Optional[str] = Field(
         default_factory=lambda: "", description="CSS class associated with the element"
     )
     html_tag_name: Optional[str] = Field(
         default_factory=lambda: "", description="HTML Tag name associated with the element"
     )
-    elementType: ElementTypeEnum = Field(..., description="Type of the element")
-    children: List["OntologyElement"] = Field(
+    elementType: ElementTypeEnum = Field(description="Type of the element")
+    children: list["OntologyElement"] = Field(
         default_factory=list, description="List of child elements"
     )
 
-    description: str = Field(..., description="Description of the element")
-    allowed_tags: List[str] = Field(..., description="HTML tags associated with the element")
+    description: str = Field(description="Description of the element")
+    allowed_tags: list[str] = Field(description="HTML tags associated with the element")
 
-    additional_attributes: Optional[dict] = Field(
-        {}, description="Optional HTML attributes or CSS properties"
+    additional_attributes: dict[str, Any] = Field(
+        default_factory=dict, description="Optional HTML attributes or CSS properties"
     )
 
-    def __init__(self, **kwargs):
+    def __init__(self, **kwargs: dict[str, Any]):
         super().__init__(**kwargs)
         if self.css_class_name == "":  # if None, then do not set
             self.css_class_name = self.__class__.__name__
         if self.html_tag_name == "":
             self.html_tag_name = self.allowed_tags[0]
         if "id" not in self.additional_attributes:
-            self.additional_attributes["id"] = str(uuid.uuid4()).replace("-", "")
+            self.additional_attributes["id"] = self.generate_unique_id()
 
-    def to_html(self, add_children=True) -> str:
+    @staticmethod
+    def generate_unique_id() -> str:
+        return str(uuid.uuid4()).replace("-", "")
+
+    def to_html(self, add_children: bool = True) -> str:
         additional_attrs = copy(self.additional_attributes)
-        if "class" in additional_attrs:
-            del additional_attrs["class"]
-
-        # TODO(Pluto) Add support for multiple classes
-        attrs = " ".join(
-            f'{key}="{value}"' if value else f"{key}" for key, value in additional_attrs.items()
-        )
+        additional_attrs.pop("class", None)
+        additional_attrs.pop("id", None)
 
+        attr_str = self._construct_attribute_string(additional_attrs)
         class_attr = f'class="{self.css_class_name}"' if self.css_class_name else ""
-        attr_str = f"{class_attr} {attrs}".strip()
 
-        children_html = (
-            ("" if not self.children else "".join(child.to_html() for child in self.children))
-            if add_children
-            else ""
+        combined_attr_str = f"{class_attr} {attr_str}".strip()
+
+        children_html = self._generate_children_html(add_children)
+
+        result_html = self._generate_final_html(combined_attr_str, children_html)
+
+        return result_html
+
+    def to_text(self, add_children: bool = True, add_img_alt_text: bool = True) -> str:
+        """
+        Returns the text representation of the element.
+
+        Args:
+            add_children: If True, the text of the children will be included.
+                            Otherwise, element is represented as single self-closing tag.
+            add_img_alt_text: If True, the alt text of the image will be included.
+        """
+        if self.children and add_children:
+            children_text = " ".join(
+                child.to_text(add_children, add_img_alt_text).strip() for child in self.children
+            )
+            return children_text
+
+        text = BeautifulSoup(self.to_html(), "html.parser").get_text().strip()
+
+        if add_img_alt_text and self.html_tag_name == "img" and "alt" in self.additional_attributes:
+            text += f" {self.additional_attributes.get('alt', '')}"
+
+        return text.strip()
+
+    def _construct_attribute_string(self, attributes: dict[str, str]) -> str:
+        return " ".join(
+            f'{key}="{value}"' if value else f"{key}" for key, value in attributes.items()
         )
-        text = "" if not self.text else self.text
+
+    def _generate_children_html(self, add_children: bool) -> str:
+        if not add_children or not self.children:
+            return ""
+        return "".join(child.to_html() for child in self.children)
+
+    def _generate_final_html(self, attr_str: str, children_html: str) -> str:
+        text = self.text or ""
 
         if text or children_html:
-            # This is either one or another, never both
-            result_html = (
-                f"<{self.html_tag_name} {attr_str}>{text} {children_html}</{self.html_tag_name}>"
-            )
+            inside_tag_text = f"{text} {children_html}".strip()
+            return f"<{self.html_tag_name} {attr_str}>{inside_tag_text}</{self.html_tag_name}>"
         else:
-            result_html = f"<{self.html_tag_name} {attr_str} />"
-        return result_html
+            return f"<{self.html_tag_name} {attr_str} />"
 
     @property
     def id(self) -> str | None:
@@ -106,12 +139,37 @@ class OntologyElement(BaseModel):
     def page_number(self) -> int | None:
         if "data-page-number" in self.additional_attributes:
             try:
-                return int(self.additional_attributes.get("data-page-number"))
+                page_attr = self.additional_attributes.get("data-page-number")
+                if page_attr is not None:
+                    return int(page_attr)
             except ValueError:
                 return None
         return None
 
 
+def remove_ids_and_class_from_table(
+    soup: BeautifulSoup, class_attr_to_keep: list[str] = ["img", "input"]
+) -> BeautifulSoup:
+    """
+    Remove id and class attributes from tags inside tables,
+    except preserve class attributes for selected tags.
+
+    Args:
+        soup: BeautifulSoup object containing the HTML
+        class_attr_to_keep: a list of tag names whose class attr will be kept
+
+    Returns:
+        BeautifulSoup: Modified soup with attributes removed
+    """
+    for tag in soup.find_all(True):
+        if tag.name.lower() == "table":  # type: ignore
+            continue  # We keep table tag
+        tag.attrs.pop("id", None)  # type: ignore
+        if tag.name.lower() not in class_attr_to_keep:  # type: ignore
+            tag.attrs.pop("class", None)  # type: ignore
+    return soup
+
+
 # Define specific elements
 class Document(OntologyElement):
     description: str = Field("Root element of the document", frozen=True)
@@ -145,13 +203,13 @@ class Paragraph(OntologyElement):
 
 class Header(OntologyElement):
     description: str = Field("The top section of a page", frozen=True)
-    elementType: ElementTypeEnum = Field(ElementTypeEnum.layout, frozen=True)
+    elementType: ElementTypeEnum = Field(ElementTypeEnum.text, frozen=True)
     allowed_tags: List[str] = Field(["header"], frozen=True)
 
 
 class Footer(OntologyElement):
     description: str = Field("The bottom section of a page", frozen=True)
-    elementType: ElementTypeEnum = Field(ElementTypeEnum.layout, frozen=True)
+    elementType: ElementTypeEnum = Field(ElementTypeEnum.text, frozen=True)
     allowed_tags: List[str] = Field(["footer"], frozen=True)
 
 
@@ -250,6 +308,11 @@ class Table(OntologyElement):
     elementType: ElementTypeEnum = Field(ElementTypeEnum.table, frozen=True)
     allowed_tags: List[str] = Field(["table"], frozen=True)
 
+    def to_html(self, add_children: bool = True) -> str:
+        soup = BeautifulSoup(super().to_html(add_children), "html.parser")
+        soup = remove_ids_and_class_from_table(soup)
+        return str(soup)
+
 
 class TableBody(OntologyElement):
     description: str = Field("A body of the table", frozen=True)
@@ -411,9 +474,14 @@ class TableOfContents(OntologyElement):
         "Header Row: L1,L2,...Ln,Value",
         frozen=True,
     )
-    elementType: ElementTypeEnum = Field(ElementTypeEnum.navigation, frozen=True)
+    elementType: ElementTypeEnum = Field(ElementTypeEnum.table, frozen=True)
     allowed_tags: List[str] = Field(["table"], frozen=True)
 
+    def to_html(self, add_children: bool = True) -> str:
+        soup = BeautifulSoup(super().to_html(add_children), "html.parser")
+        soup = remove_ids_and_class_from_table(soup)
+        return str(soup)
+
 
 class Index(OntologyElement):
     description: str = Field("An alphabetical list of terms and their page numbers", frozen=True)
@@ -438,6 +506,13 @@ class FormFieldValue(OntologyElement):
     elementType: ElementTypeEnum = Field(ElementTypeEnum.form, frozen=True)
     allowed_tags: List[str] = Field(["input"], frozen=True)
 
+    def to_text(self, add_children: bool = True, add_img_alt_text: bool = True) -> str:
+        text = super().to_text(add_children, add_img_alt_text)
+        value = self.additional_attributes.get("value", "")
+        if not value:
+            return text
+        return f"{text} {value}".strip()
+
 
 class Checkbox(OntologyElement):
     description: str = Field("A small box that can be checked or unchecked", frozen=True)
