@@ -10,7 +10,7 @@ import requests
 from lxml import etree
 
 from unstructured.chunking import add_chunking_strategy
-from unstructured.documents.elements import Element
+from unstructured.documents.elements import Element, ElementType
 from unstructured.file_utils.encoding import read_txt_file
 from unstructured.file_utils.model import FileType
 from unstructured.partition.common.metadata import apply_metadata, get_last_modified_date
@@ -36,6 +36,9 @@ def partition_html(
     skip_headers_and_footers: bool = False,
     detection_origin: Optional[str] = None,
     html_parser_version: Literal["v1", "v2"] = "v1",
+    image_alt_mode: Optional[Literal["to_text"]] = "to_text",
+    extract_image_block_to_payload: bool = False,
+    extract_image_block_types: Optional[list[str]] = None,
     **kwargs: Any,
 ) -> list[Element]:
     """Partitions an HTML document into its constituent elements.
@@ -65,6 +68,9 @@ def partition_html(
     html_parser_version (Literal['v1', 'v2']):
         The version of the HTML parser to use. The default is 'v1'. For 'v2' the parser will
         use the ontology schema to parse the HTML document.
+
+    image_alt_mode (Literal['to_text']):
+        When set 'to_text', the v2 parser will include the alternative text of images in the output.
     """
     # -- parser rejects an empty str, nip that edge-case in the bud here --
     if text is not None and text.strip() == "" and not file and not filename and not url:
@@ -81,6 +87,9 @@ def partition_html(
         skip_headers_and_footers=skip_headers_and_footers,
         detection_origin=detection_origin,
         html_parser_version=html_parser_version,
+        image_alt_mode=image_alt_mode,
+        extract_image_block_types=extract_image_block_types,
+        extract_image_block_to_payload=extract_image_block_to_payload,
     )
 
     return list(_HtmlPartitioner.iter_elements(opts))
@@ -102,6 +111,9 @@ class HtmlPartitionerOptions:
         skip_headers_and_footers: bool,
         detection_origin: str | None,
         html_parser_version: Literal["v1", "v2"] = "v1",
+        image_alt_mode: Optional[Literal["to_text"]] = "to_text",
+        extract_image_block_types: Optional[list[str]] = None,
+        extract_image_block_to_payload: bool = False,
     ):
         self._file_path = file_path
         self._file = file
@@ -113,20 +125,15 @@ class HtmlPartitionerOptions:
         self._skip_headers_and_footers = skip_headers_and_footers
         self._detection_origin = detection_origin
         self._html_parser_version = html_parser_version
+        self._image_alt_mode = image_alt_mode
+        self._extract_image_block_types = extract_image_block_types
+        self._extract_image_block_to_payload = extract_image_block_to_payload
 
     @lazyproperty
     def detection_origin(self) -> str | None:
         """Trace of initial partitioner to be included in metadata for debugging purposes."""
         return self._detection_origin
 
-    @lazyproperty
-    def encoding(self) -> str | None:
-        """Caller-provided encoding used to store HTML character stream as bytes.
-
-        `None` when no encoding was provided and encoding should be auto-detected.
-        """
-        return self._encoding
-
     @lazyproperty
     def html_text(self) -> str:
         """The HTML document as a string, loaded from wherever the caller specified."""
@@ -172,6 +179,11 @@ class HtmlPartitionerOptions:
         """When html_parser_version=='v2', HTML elements follow ontology schema."""
         return self._html_parser_version
 
+    @lazyproperty
+    def add_img_alt_text(self) -> bool:
+        """When True, the alternative text of images is included in the output."""
+        return self._image_alt_mode == "to_text"
+
 
 class _HtmlPartitioner:
     """Partition HTML document into document-elements."""
@@ -179,6 +191,15 @@ class _HtmlPartitioner:
     def __init__(self, opts: HtmlPartitionerOptions):
         self._opts = opts
 
+    def _should_include_image_base64(self, element: Element) -> bool:
+        """Determines if an image_base64 element should be included in the output."""
+        return (
+            element.category == ElementType.IMAGE
+            and self._opts._extract_image_block_to_payload
+            and self._opts._extract_image_block_types is not None
+            and "Image" in self._opts._extract_image_block_types
+        )
+
     @classmethod
     def iter_elements(cls, opts: HtmlPartitionerOptions) -> Iterator[Element]:
         """Partition HTML document provided by `opts` into document-elements."""
@@ -189,6 +210,11 @@ class _HtmlPartitioner:
 
         Elements appear in document order.
         """
+        # -- handle empty or whitespace-only HTML content --
+        html_text = self._opts.html_text
+        if not html_text or html_text.strip() == "":
+            return
+
         elements_iter = (
             self._main.iter_elements()
             if self._opts.html_parser_version == "v1"
@@ -198,6 +224,11 @@ class _HtmlPartitioner:
         for e in elements_iter:
             e.metadata.last_modified = self._opts.last_modified
             e.metadata.detection_origin = self._opts.detection_origin
+
+            # -- remove <image_base64> if not requested --
+            if not self._should_include_image_base64(e):
+                e.metadata.image_base64 = None
+                e.metadata.image_mime_type = None
             yield e
 
     @lazyproperty
@@ -220,7 +251,7 @@ class _HtmlPartitioner:
         # -- remove a variety of HTML element types like <script> and <style> that we prefer not
         # -- to encounter while parsing.
         etree.strip_elements(
-            root, ["del", "img", "link", "meta", "noscript", "script", "style"], with_tail=False
+            root, ["del", "link", "meta", "noscript", "script", "style"], with_tail=False
         )
 
         # -- remove <header> and <footer> tags if the caller doesn't want their contents --
@@ -238,6 +269,13 @@ class _HtmlPartitioner:
     def _from_ontology(self) -> List[Element]:
         """Convert an ontology elements represented in HTML to an ontology element."""
         html_text = self._opts.html_text
+
+        # -- handle empty or whitespace-only HTML content --
+        if not html_text or html_text.strip() == "":
+            return []
+
         ontology = parse_html_to_ontology(html_text)
-        unstructured_elements = ontology_to_unstructured_elements(ontology)
+        unstructured_elements = ontology_to_unstructured_elements(
+            ontology, add_img_alt_text=self._opts.add_img_alt_text
+        )
         return unstructured_elements
