@@ -3,17 +3,18 @@
 from __future__ import annotations
 
 import io
-from tempfile import SpooledTemporaryFile
-from typing import IO, Any, Iterator, Optional, cast
+from typing import IO, Any, Iterator, Optional
 
 import networkx as nx
 import numpy as np
 import pandas as pd
-from lxml.html.soupparser import fromstring as soupparser_fromstring  # pyright: ignore
+from msoffcrypto import OfficeFile
+from msoffcrypto.exceptions import FileFormatError
 from typing_extensions import Self, TypeAlias
 
 from unstructured.chunking import add_chunking_strategy
 from unstructured.cleaners.core import clean_bullets
+from unstructured.common.html_table import HtmlTable
 from unstructured.documents.elements import (
     Element,
     ElementMetadata,
@@ -22,11 +23,10 @@ from unstructured.documents.elements import (
     Table,
     Text,
     Title,
-    process_metadata,
 )
-from unstructured.file_utils.filetype import FileType, add_metadata_with_filetype
-from unstructured.partition.common import get_last_modified_date, get_last_modified_date_from_file
-from unstructured.partition.lang import apply_lang_metadata
+from unstructured.errors import UnprocessableEntityError
+from unstructured.file_utils.model import FileType
+from unstructured.partition.common.metadata import apply_metadata, get_last_modified_date
 from unstructured.partition.text_type import (
     is_bulleted_text,
     is_possible_narrative_text,
@@ -40,21 +40,15 @@ _CellCoordinate: TypeAlias = "tuple[int, int]"
 DETECTION_ORIGIN: str = "xlsx"
 
 
-@process_metadata()
-@add_metadata_with_filetype(FileType.XLSX)
+@apply_metadata(FileType.XLSX)
 @add_chunking_strategy
 def partition_xlsx(
     filename: Optional[str] = None,
+    *,
     file: Optional[IO[bytes]] = None,
-    metadata_filename: Optional[str] = None,
-    include_metadata: bool = True,
-    infer_table_structure: bool = True,
-    languages: Optional[list[str]] = ["auto"],
-    detect_language_per_element: bool = False,
-    metadata_last_modified: Optional[str] = None,
-    include_header: bool = False,
     find_subtable: bool = True,
-    date_from_file_object: bool = False,
+    include_header: bool = False,
+    infer_table_structure: bool = True,
     starting_page_number: int = 1,
     **kwargs: Any,
 ) -> list[Element]:
@@ -66,41 +60,25 @@ def partition_xlsx(
         A string defining the target filename path.
     file
         A file-like object using "rb" mode --> open(filename, "rb").
-    include_metadata
-        Determines whether or not metadata is included in the output.
+    find_subtable
+        Detect "subtables" on each worksheet and partition each of those as a separate `Table`
+        element. When `False`, each worksheet is partitioned as a single `Table` element. A
+        subtable is a contiguous block of cells with more than two cells in each row.
     infer_table_structure
         If True, any Table elements that are extracted will also have a metadata field
         named "text_as_html" where the table's text content is rendered into an html string.
         I.e., rows and cells are preserved.
         Whether True or False, the "text" field is always present in any Table element
         and is the text content of the table (no structure).
-    languages
-        User defined value for metadata.languages if provided. Otherwise language is detected
-        using naive Bayesian filter via `langdetect`. Multiple languages indicates text could be
-        in either language.
-        Additional Parameters:
-            detect_language_per_element
-                Detect language per element instead of at the document level.
-    metadata_last_modified
-        The day of the last modification
     include_header
         Determines whether or not header info is included in text and medatada.text_as_html
-    date_from_file_object
-        Applies only when providing file via `file` parameter. If this option is True, attempt
-        infer last_modified metadata from bytes, otherwise set it to None.
     """
     opts = _XlsxPartitionerOptions(
-        date_from_file_object=date_from_file_object,
-        detect_language_per_element=detect_language_per_element,
-        file=file,
         file_path=filename,
+        file=file,
         find_subtable=find_subtable,
         include_header=include_header,
-        include_metadata=include_metadata,
         infer_table_structure=infer_table_structure,
-        languages=languages,
-        metadata_file_path=metadata_filename,
-        metadata_last_modified=metadata_last_modified,
     )
 
     elements: list[Element] = []
@@ -108,35 +86,21 @@ def partition_xlsx(
         opts.sheets.items(), start=starting_page_number
     ):
         if not opts.find_subtable:
-            html_text = (
-                sheet.to_html(  # pyright: ignore[reportUnknownMemberType]
-                    index=False, header=opts.include_header, na_rep=""
-                )
-                if opts.infer_table_structure
-                else None
-            )
-            # XXX: `html_text` can be `None`. What happens on this call in that case?
-            text = cast(
-                str,
-                soupparser_fromstring(  # pyright: ignore[reportUnknownMemberType]
-                    html_text
-                ).text_content(),
+            html_table = HtmlTable.from_html_text(
+                sheet.to_html(index=False, header=opts.include_header, na_rep="")
             )
 
-            if opts.include_metadata:
-                metadata = ElementMetadata(
-                    text_as_html=html_text,
-                    page_name=sheet_name,
-                    page_number=page_number,
-                    filename=opts.metadata_file_path,
-                    last_modified=opts.last_modified,
-                )
-                metadata.detection_origin = DETECTION_ORIGIN
-            else:
-                metadata = ElementMetadata()
+            metadata = ElementMetadata(
+                text_as_html=html_table.html if infer_table_structure else None,
+                page_name=sheet_name,
+                page_number=page_number,
+                filename=opts.metadata_file_path,
+                last_modified=opts.last_modified,
+            )
+            metadata.detection_origin = DETECTION_ORIGIN
+
+            elements.append(Table(text=html_table.text, metadata=metadata))
 
-            table = Table(text=text, metadata=metadata)
-            elements.append(table)
         else:
             for component in _ConnectedComponents.from_worksheet_df(sheet):
                 subtable_parser = _SubtableParser(component.subtable)
@@ -150,19 +114,13 @@ def partition_xlsx(
                 # -- emit core-table (if it exists) as a `Table` element --
                 core_table = subtable_parser.core_table
                 if core_table is not None:
-                    html_text = core_table.to_html(  # pyright: ignore[reportUnknownMemberType]
-                        index=False, header=opts.include_header, na_rep=""
+                    html_table = HtmlTable.from_html_text(
+                        core_table.to_html(index=False, header=opts.include_header, na_rep="")
                     )
-                    text = cast(
-                        str,
-                        soupparser_fromstring(  # pyright: ignore[reportUnknownMemberType]
-                            html_text
-                        ).text_content(),
-                    )
-                    element = Table(text=text)
+                    element = Table(text=html_table.text)
                     element.metadata = _get_metadata(sheet_name, page_number, opts)
                     element.metadata.text_as_html = (
-                        html_text if opts.infer_table_structure else None
+                        html_table.html if opts.infer_table_structure else None
                     )
                     elements.append(element)
 
@@ -174,13 +132,6 @@ def partition_xlsx(
                     element.metadata = _get_metadata(sheet_name, page_number, opts)
                     elements.append(element)
 
-    elements = list(
-        apply_lang_metadata(
-            elements=elements,
-            languages=opts.languages,
-            detect_language_per_element=opts.detect_language_per_element,
-        ),
-    )
     return elements
 
 
@@ -190,34 +141,17 @@ class _XlsxPartitionerOptions:
     def __init__(
         self,
         *,
-        date_from_file_object: bool,
-        detect_language_per_element: bool,
-        file: Optional[IO[bytes]],
         file_path: Optional[str],
+        file: Optional[IO[bytes]],
         find_subtable: bool,
         include_header: bool,
-        include_metadata: bool,
         infer_table_structure: bool,
-        languages: Optional[list[str]],
-        metadata_file_path: Optional[str],
-        metadata_last_modified: Optional[str],
     ):
-        self._date_from_file_object = date_from_file_object
-        self._detect_language_per_element = detect_language_per_element
-        self._file = file
         self._file_path = file_path
+        self._file = file
         self._find_subtable = find_subtable
         self._include_header = include_header
-        self._include_metadata = include_metadata
         self._infer_table_structure = infer_table_structure
-        self._languages = languages
-        self._metadata_file_path = metadata_file_path
-        self._metadata_last_modified = metadata_last_modified
-
-    @lazyproperty
-    def detect_language_per_element(self) -> bool:
-        """When True, detect language on element-by-element basis instead of document level."""
-        return self._detect_language_per_element
 
     @lazyproperty
     def find_subtable(self) -> bool:
@@ -237,66 +171,46 @@ class _XlsxPartitionerOptions:
         """True when column headers should be included in tables."""
         return self._include_header
 
-    @lazyproperty
-    def include_metadata(self) -> bool:
-        """True when partitioner should apply metadata to emitted elements."""
-        return self._include_metadata
-
     @lazyproperty
     def infer_table_structure(self) -> bool:
         """True when partitioner should compute and apply `text_as_html` metadata."""
         return self._infer_table_structure
 
-    @lazyproperty
-    def languages(self) -> Optional[list[str]]:
-        """User-specified language(s) of this document.
-
-        When `None`, language is detected using naive Bayesian filter via `langdetect`. Multiple
-        language codes indicate text could be in any of those languages.
-        """
-        return self._languages
-
     @lazyproperty
     def last_modified(self) -> Optional[str]:
         """The best last-modified date available, None if no sources are available."""
-        # -- value explicitly specified by caller takes precedence --
-        if self._metadata_last_modified:
-            return self._metadata_last_modified
-
-        if self._file_path:
-            return get_last_modified_date(self._file_path)
-
-        if self._file:
-            return (
-                get_last_modified_date_from_file(self._file)
-                if self._date_from_file_object
-                else None
-            )
-
-        return None
+        return get_last_modified_date(self._file_path) if self._file_path else None
 
     @lazyproperty
     def metadata_file_path(self) -> str | None:
         """The best available file-path for this document or `None` if unavailable."""
-        return self._metadata_file_path or self._file_path
+        return self._file_path
 
     @lazyproperty
     def sheets(self) -> dict[str, pd.DataFrame]:
         """The spreadsheet worksheets, each as a data-frame mapped by sheet-name."""
-        if file_path := self._file_path:
-            return pd.read_excel(  # pyright: ignore[reportUnknownMemberType]
-                file_path, sheet_name=None, header=self.header_row_idx
-            )
+        try:
+            office_file = OfficeFile(io.BytesIO(self._file_bytes))
+        except FileFormatError as e:
+            raise UnprocessableEntityError("Not a valid XLSX file.") from e
 
-        if f := self._file:
-            if isinstance(f, SpooledTemporaryFile):
-                f.seek(0)
-                f = io.BytesIO(f.read())
-            return pd.read_excel(  # pyright: ignore[reportUnknownMemberType]
-                f, sheet_name=None, header=self.header_row_idx
-            )
+        if office_file.is_encrypted():
+            raise UnprocessableEntityError("XLSX file is password protected.")
 
-        raise ValueError("Either 'filename' or 'file' argument must be specified.")
+        return pd.read_excel(
+            io.BytesIO(self._file_bytes), sheet_name=None, header=self.header_row_idx
+        )
+
+    @lazyproperty
+    def _file_bytes(self) -> bytes:
+        if file := self._file:
+            file.seek(0)
+            return file.read()
+        elif self._file_path:
+            with open(self._file_path, "rb") as file:
+                return file.read()
+        else:
+            raise ValueError("Either 'filename' or 'file' argument must be specified.")
 
 
 class _ConnectedComponent:
@@ -382,7 +296,7 @@ class _ConnectedComponents:
         max_row, max_col = self._worksheet_df.shape
         node_array = np.indices((max_row, max_col)).T
         empty_cells = self._worksheet_df.isna().T
-        nodes_to_remove = [tuple(pair) for pair in node_array[empty_cells]]
+        nodes_to_remove = [tuple(pair) for pair in node_array[empty_cells]]  # pyright: ignore
 
         graph: nx.Graph = nx.grid_2d_graph(max_row, max_col)  # pyright: ignore
         graph.remove_nodes_from(nodes_to_remove)  # pyright: ignore
@@ -498,7 +412,7 @@ class _SubtableParser:
         """Index of each single-cell row in subtable, in top-down order."""
 
         def iter_single_cell_row_idxs() -> Iterator[int]:
-            for idx, (_, row) in enumerate(self._subtable.iterrows()):  # pyright: ignore
+            for idx, (_, row) in enumerate(self._subtable.iterrows()):
                 if row.count() != 1:
                     continue
                 yield idx
@@ -541,14 +455,9 @@ def _create_element(text: str) -> Element:
 def _get_metadata(
     sheet_name: str, page_number: int, opts: _XlsxPartitionerOptions
 ) -> ElementMetadata:
-    """Returns metadata depending on `include_metadata` flag"""
-    return (
-        ElementMetadata(
-            page_name=sheet_name,
-            page_number=page_number,
-            filename=opts.metadata_file_path,
-            last_modified=opts.last_modified,
-        )
-        if opts.include_metadata
-        else ElementMetadata()
+    return ElementMetadata(
+        page_name=sheet_name,
+        page_number=page_number,
+        filename=opts.metadata_file_path,
+        last_modified=opts.last_modified,
     )
