@@ -2,7 +2,6 @@ from __future__ import annotations
 
 import asyncio
 import functools
-import html
 import importlib
 import inspect
 import json
@@ -11,7 +10,6 @@ import platform
 import subprocess
 import tempfile
 import threading
-from datetime import datetime
 from functools import wraps
 from itertools import combinations
 from typing import (
@@ -23,7 +21,6 @@ from typing import (
     Iterator,
     List,
     Optional,
-    Sequence,
     Tuple,
     TypeVar,
     cast,
@@ -62,36 +59,6 @@ def get_call_args_applying_defaults(
     return call_args
 
 
-def htmlify_matrix_of_cell_texts(matrix: Sequence[Sequence[str]]) -> str:
-    """Form an HTML table from "rows" and "columns" of `matrix`.
-
-    Character overhead is minimized:
-    - No whitespace padding is added for human readability
-    - No newlines ("\n") are added
-    - No `<thead>`, `<tbody>`, or `<tfoot>` elements are used; we can't tell where those might be
-      semantically appropriate anyway so at best they would consume unnecessary space and at worst
-      would be misleading.
-    """
-
-    def iter_trs(rows_of_cell_strs: Sequence[Sequence[str]]) -> Iterator[str]:
-        for row_cell_strs in rows_of_cell_strs:
-            # -- suppress emission of rows with no cells --
-            if not row_cell_strs:
-                continue
-            yield f"<tr>{''.join(iter_tds(row_cell_strs))}</tr>"
-
-    def iter_tds(row_cell_strs: Sequence[str]) -> Iterator[str]:
-        for s in row_cell_strs:
-            # -- take care of things like '<' and '>' in the text --
-            s = html.escape(s)
-            # -- substitute <br/> elements for line-feeds in the text --
-            s = "<br/>".join(s.split("\n"))
-            # -- strip leading and trailing whitespace, wrap it up and go --
-            yield f"<td>{s.strip()}</td>"
-
-    return f"<table>{''.join(iter_trs(matrix))}</table>" if matrix else ""
-
-
 def is_temp_file_path(file_path: str) -> bool:
     """True when file_path is in the Python-defined tempdir.
 
@@ -270,36 +237,6 @@ def dependency_exists(dependency: str):
     return True
 
 
-def validate_date_args(date: Optional[str] = None) -> bool:
-    """Validate whether the provided date string satisfies any of the supported date formats.
-
-    Used by unstructured/ingest/connector/biomed.py
-
-    Returns `True` if the date string satisfies any of the supported formats, otherwise raises
-    `ValueError`.
-
-    Supported Date Formats:
-        - 'YYYY-MM-DD'
-        - 'YYYY-MM-DDTHH:MM:SS'
-        - 'YYYY-MM-DD+HH:MM:SS'
-        - 'YYYY-MM-DDTHH:MM:SS±HHMM'
-    """
-    if not date:
-        raise ValueError("The argument date is None.")
-
-    for format in DATE_FORMATS:
-        try:
-            datetime.strptime(date, format)
-            return True
-        except ValueError:
-            pass
-
-    raise ValueError(
-        f"The argument {date} does not satisfy the format:"
-        f" YYYY-MM-DD or YYYY-MM-DDTHH:MM:SS or YYYY-MM-DD+HH:MM:SS or YYYY-MM-DDTHH:MM:SS±HHMM",
-    )
-
-
 def _first_and_remaining_iterator(it: Iterable[_T]) -> Tuple[_T, Iterator[_T]]:
     iterator = iter(it)
     try:
@@ -355,6 +292,7 @@ def scarf_analytics():
                     + "&gpu="
                     + str(gpu_present)
                     + "&dev=true",
+                    timeout=10,
                 )
             else:
                 requests.get(
@@ -369,6 +307,7 @@ def scarf_analytics():
                     + "&gpu="
                     + str(gpu_present)
                     + "&dev=false",
+                    timeout=10,
                 )
     except Exception:
         pass
@@ -458,12 +397,10 @@ def is_parent_box(parent_target: Box, child_target: Box, add: float = 0.0) -> bo
         and (child_target[2] <= parent_targets[2] and child_target[3] <= parent_targets[3])
     ):
         return True
-    if len(child_target) == 2 and (
+    return len(child_target) == 2 and (
         parent_targets[0] <= child_target[0] <= parent_targets[2]
         and parent_targets[1] <= child_target[1] <= parent_targets[3]
-    ):
-        return True
-    return False
+    )
 
 
 def calculate_overlap_percentage(
